<!-- HTML page from https://github.com/rameerez/embargoed/blob/main/public/maintenance.html -->

<!DOCTYPE html>
<html>
  <head>
    <meta charset="UTF-8">
    <title>Page blocked for 🇷🇺 Russian visitors</title>

    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@4.6.0/dist/css/bootstrap.min.css" integrity="sha384-B0vP5xmATw1+K9KRQjQERJvTumQW0nPEzvF6L/Z6nronJ3oUOFUFpCjEUQouq2+l" crossorigin="anonymous">


    <style type="text/css">

      *{
        font-family: Lato, Arial, Helvetica, sans-serif;
      }

      body{
        margin: 0;
        background-color: #f6f9fc;
        height: 100vh;
      }

      .card{
        position: relative;
        padding: 3em 3em;
        text-align: center;
        background: #ffffff;
        color: rgb(66, 84, 102);
        box-shadow: rgba(50, 50, 93, 0.25) 0px 50px 100px -20px, rgba(0, 0, 0, 0.3) 0px 30px 60px -30px;
        border-radius: 8px;
      }

      h1{
        margin: 0;
        color: #242424;
        font-size: 26pt;
        margin-bottom: 1em;
        font-weight: bolder;
      }

    </style>

  </head>
  <body>

    <div class="container h-100">
      <div class="row align-items-center h-100">
        <div class="col-12 col-md-8 offset-md-1 col-lg-6 offset-lg-3 mx-auto">
          <div class="card">
            <h1>We're sorry, Russians.</h1>

            <p>We've blocked this website for Russian visitors.</p>
            <p>On Feb 24, 2022 Russian forces started invading Ukraine. We know you, a regular person, are not to blame. But your leaders have chosen a very violent path breaking international law, and we've chosen not to do business with Russian citizens at the time. We condemn this crime.</p>
            <p>We don't like this situation either, and we'd love to do business with Russia again soon. But only you can make it stop.</p>
            <p><b>Protest in social media and in the streets</b> to demand your leaders stop this invasion. Peace and diplomacy are the only way forward.</p>
            <p>🇺🇦 Slava Ukraini</p>
          </div>
        </div>
      </div>
    </div>

  </body>
</html>